using System;
using System.Drawing;
using System.ComponentModel;
using System.Runtime.Serialization;
using System.Diagnostics;
using System.Windows.Forms;

using Syncfusion.Windows.Forms.Diagram;
namespace Links

{
	/// <summary>
	/// Interactive tool for inserting ports into a diagram.
	/// </summary>
	/// <remarks>
	/// <seealso cref="Syncfusion.Windows.Forms.Diagram.Tool"/>
	/// <seealso cref="Syncfusion.Windows.Forms.Diagram.IMouseEventReceiver"/>
	/// <seealso cref="Syncfusion.Windows.Forms.Diagram.InsertNodesCmd"/>
	/// <seealso cref="Syncfusion.Windows.Forms.Diagram.Port"/>
	/// </remarks>
	public class MyPortTool : Syncfusion.Windows.Forms.Diagram.PortTool, IMouseEventReceiver
	{


		public MyPortTool() : base(Resources.Strings.Toolnames.Get("MyPortTool"))
	{
	}

		public MyPortTool(string name) : base(name)
	{
	}

		/// <summary>
		/// 
		/// </summary>
		protected override void OnActivate()
		{
			ChangeCursor(Cursors.Cross);
		}

		/// <summary>
		/// 
		/// </summary>
		protected override void OnDeactivate()
		{
			this.drawing = false;
			base.OnDeactivate();
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="e"></param>
		void IMouseEventReceiver.MouseDown(System.Windows.Forms.MouseEventArgs e)
		{
			if (this.Active)
			{
				if (e.Button == MouseButtons.Left)
				{
					this.drawing = true;
				}
			}
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="e"></param>
		void IMouseEventReceiver.MouseMove(System.Windows.Forms.MouseEventArgs e)
		{
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="e"></param>
		void IMouseEventReceiver.MouseUp(System.Windows.Forms.MouseEventArgs e)
		{
			if (this.Active && this.drawing)
			{
				System.Drawing.Point pt = this.Controller.View.SnapPointToGrid(e.X, e.Y);

				Point[] devicePts = { pt };
				PointF[] viewPts;
				PointF[] worldPts;
				Controller.View.DeviceToView(devicePts, out viewPts);
				Controller.View.ViewToWorld(viewPts, out worldPts);

				Syncfusion.Windows.Forms.Diagram.CirclePort port = new Syncfusion.Windows.Forms.Diagram.CirclePort(worldPts[0]);
				port.LineStyle.LineColor = Color.Red;
				InsertNodesCmd cmd = new InsertNodesCmd();
				cmd.Nodes.Add(port);

				try
				{
					this.Controller.ExecuteCommand(cmd);
				}
				catch (Exception ex)
				{
					this.Controller.DeactivateTool(this);
					throw ex;
				}

				this.Controller.DeactivateTool(this);
			}
		}


	}
}
